package com.diagbot.rule;

import com.diagbot.dto.BillMsg;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.RuleSimpleDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.enums.ConEnum;
import com.diagbot.enums.RedisEnum;
import com.diagbot.enums.TypeEnum;
import com.diagbot.model.entity.AllergyMedicine;
import com.diagbot.model.entity.Negative;
import com.diagbot.model.label.PastLabel;
import com.diagbot.util.CoreUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.MsgNewUtil;
import com.diagbot.util.RedisUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.Drug;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.List;
import java.util.Map;

/**
 * @description: 其他特殊规则
 * @author: zhoutg
 * @time: 2020/8/3 14:47
 */
@Component
public class OtherRule {

    @Autowired
    MsgNewUtil msgNewUtil;
    @Autowired
    RedisUtil redisUtil;

    /**
     * 过敏原自身过敏，如果规则已存在，就不再比较；如果不存在，比较是否与自身过敏
     *
     * @param
     * @return
     */
    public void allergy(WordCrfDTO wordCrfDTO, IndicationDTO res) {
        // 药物过敏源
        PastLabel pastLabel = wordCrfDTO.getPastLabel();
        List<AllergyMedicine> allergyMedicines = pastLabel.getAllergyMedicines();
        if (ListUtil.isEmpty(wordCrfDTO.getDrugOrder()) || ListUtil.isEmpty(allergyMedicines)) {
            return;
        }
        // 获取已维护的自身过敏规则，如果包含standName就不用再比较
        Map<String, Integer> allergyMap = redisUtil.get(RedisEnum.drugAllergen.getName());
        for (Drug drug : wordCrfDTO.getDrugOrder()) {
            for (AllergyMedicine allergy : allergyMedicines) {
                String name = allergy.getName();
                String standName = allergy.getStandName();
                Negative negative = allergy.getNegative(); // null表示阳性
                if (allergyMap == null || !allergyMap.containsKey(standName)) {
                    // 执行到这里说明自身过敏的规则没有维护
                    if (negative == null && StringUtil.isNotBlank(drug.getUniqueName()) && drug.getUniqueName().equals(standName)) {
                        RuleSimpleDTO ruleSimpleDTO = new RuleSimpleDTO();
                        ruleSimpleDTO.setInputName(drug.getName());
                        ruleSimpleDTO.setLibName(drug.getUniqueName());
                        ruleSimpleDTO.setLibTypeName(TypeEnum.drug.getName());
                        ruleSimpleDTO.setContent(name);
                        ruleSimpleDTO.setConType(ConEnum.allergicmeds.getName());
                        BillMsg billMsg = msgNewUtil.getCommonBillMsg(ruleSimpleDTO);
                        CoreUtil.addBeanToList(res.getBillMsgList(), billMsg);
                    }
                }
            }
        }
    }

}
